@@ -70,7 +70,7 @@
   // with the offcanvas wrapper to make the slide in navigation
   // working on Safari and on iOS devices
   function prepareHTML() {
-    var scripts = $("body script").not("[type='text/x-handlebars-template']").detach();
+    var scripts = $("body script[type='text/javascript'], body script:not([type])").detach();
     $("body").wrapInner(offcanvasWrapper());
     scripts.each(function(script) {
       $(script).parent().append(script);
@@ -118,7 +118,10 @@
       root.off(vendorTransitionEnd.join(" "));
       $('#ftw-mobile-menu').attr('aria-hidden', 'false');
       $('#ftw-mobile-menu').trigger('mobilenav:nav:opened');
-      arrowScrollController.selectCurrent();
+
+      if ($('.topLevelTabs').length === 1) {
+        arrowScrollController.selectCurrent();
+      }
     });
   }
 
@@ -329,7 +332,7 @@
         event.preventDefault();
         render_path(mobileTree.getPhysicalPath($(this).attr('href')));
       });
-    }, link.data('mobile_startup_cachekey'));
+    }, link.data('mobile_startup_cachekey'), settings.ignoreExcludeFromNav);
     $('#ftw-mobile-menu').trigger('mobilenav:initialized');
   }
 
@@ -344,6 +347,12 @@
     }
   })
   .ready(function() {
+
+    if ($('#ftw-mobile-wrapper').length === 0) {
+      // Do not anything, since ftw.mobile html structure is not available
+      return;
+    }
+
     Handlebars.registerPartial("list", $("#ftw-mobile-navigation-list-template").html());
 
     var translations = $("#ftw-mobile-menu-buttons").data('i18n');
